/*
 MozziFMOnePot firmware play a sound through an oscillator
 itself modulated by another oscillator.
 
 Turning the pot change the frequency of the modulating oscillator
 
 It demonstrates how to make a frequency modulation by using a phase modulation
 
 Freely inspired by the Vibrato example of Mozzi library by Tim Barrass.
 *  Mozzi help/discussion/announcements:
 *  https://groups.google.com/forum/#!forum/mozzi-users
 
 Written by Julien Bayle, this example code is in the public domain
 
 This code is related to the book "C programming for Arduino" written by Julien Bayle
 and published by Packt Publishing.
 
 http://cprogrammingforarduino.com
 
 */

#include <MozziGuts.h>
#include <Oscil.h>
#include <tables/cos8192_int8.h> // table for Oscils to play
#include <utils.h> // for mtof

#define CONTROL_RATE 64 // powers of 2 please

Oscil<COS8192_NUM_CELLS, AUDIO_RATE> aCos(COS8192_DATA);
Oscil<COS8192_NUM_CELLS, AUDIO_RATE> aVibrato(COS8192_DATA);

const long intensityMax = 500;

int potPin = A0;
int potValue = 0;

void setup(){
  startMozzi(CONTROL_RATE);
  aCos.setFreq(mtof(random(21,80)));
  aVibrato.setFreq(10.f);
}

void loop(){
  audioHook();
}

void updateControl(){
  potValue = analogRead(potPin);
}

int updateAudio(){
  long vibrato = map(potValue, 0, 1024, 0, intensityMax) * aVibrato.next();
  return (int)aCos.phMod(vibrato);
}
