/*
 MozziMIDI firmware features a way to produce & alter sound while 
 receiving MIDI notes & control change (CC) messages.
 
 This example has been written by Mozzi library's creator Tim Barrass.
 Thanks a lot to him.

 This code use the  arduinomidi library
 http://arduinomidilib.sourceforge.net/

 This code is related to the book "C programming for Arduino" written by Julien Bayle
 and published by Packt Publishing.
 
 http://cprogrammingforarduino.com
 
 */

#include <MIDI.h>
#include <MozziGuts.h>
#include <Oscil.h> // oscillator template
#include <Line.h> // for envelope
#include <utils.h> // for mtof
#include <tables/sin2048_int8.h> // sine table for oscillator


// use #define for CONTROL_RATE, not a constant
#define CONTROL_RATE 128 // powers of 2 please

// declare an oscillator using a sinetone wavetable
// use: Oscil <table_size, update_rate> oscilName (wavetable)
Oscil <SIN2048_NUM_CELLS, AUDIO_RATE> aSin(SIN2048_DATA);

// for envelope
Line <unsigned int> aGain;
unsigned int release_control_steps = CONTROL_RATE; // 1 second of control
unsigned int release_audio_steps = 16384; // 1 second of audio
int fade_counter;

float vol= 1. ; // store the master output volume

unsigned int freq; // to convey control info from MIDI handler to updateControl()


void HandleControlChange(byte channel, byte CCnumber, byte value) { 
  switch(CCnumber){
    case 100:
      vol = map(value,0, 127, 0., 1.);
    break;
  }
}

void HandleNoteOn(byte channel, byte pitch, byte velocity) { 

  // scale velocity for high resolution linear fade on Note-off later
  freq = mtof(pitch);
  aGain.set(velocity<<8); // might need a fade-in to avoid clicks

}


void HandleNoteOff(byte channel, byte pitch, byte velocity) { 

  // scale velocity for high resolution linear fade on Note-off later
  aGain.set(0,release_audio_steps);
  fade_counter = release_control_steps;
}

void setup() {
  
  // Initiate MIDI communications, listen to all channels
  MIDI.begin(MIDI_CHANNEL_OMNI);    

  // Connect the HandleControlChange function to the library, so it is called upon reception of a NoteOn.
  MIDI.setHandleControlChange(HandleControlChange); // Put only the name of the function
  
    // Connect the HandleNoteOn function to the library, so it is called upon reception of a NoteOn.
  MIDI.setHandleNoteOn(HandleNoteOn);  // Put only the name of the function


   // Connect the HandleNoteOn function to the library, so it is called upon reception of a NoteOn.
  MIDI.setHandleNoteOff(HandleNoteOff);  // Put only the name of the function

  aSin.setFreq(440u); // default frequency
  startMozzi(CONTROL_RATE); 
}


void updateControl(){
  // Ideally, call MIDI.read the fastest you can for real-time performance.
  // In practice, there is a balance required between real-time 
  // audio generation and a responsive midi control rate.
  MIDI.read();
  
  aSin.setFreq(freq);

  if (fade_counter-- <=0) aGain.set(0,0,2); // a line along 0
}


int updateAudio(){
  // aGain is scaled down to usable range
  return (int) ((aGain.next()>>8) * aSin.next() * vol )>>8; // >>8 shifts the multiplied result back to usable output range
}


void loop() {
    audioHook(); // required here
} 
