/*
 locateMe firmware reads data coming from the Parallax GPS Receive wired to digital pin 0
 and writes formatted received data to the USB port, for computer serial monitoring and displaying
 
 Written by Julien Bayle, this example code is under Creative Commons CC-BY-SA
 
 This code is related to the book "C programming for Arduino" written by Julien Bayle
 and published by Packt Publishing.
 
 http://cprogrammingforarduino.com
 
 */

int rxPin = 0;                    // RX PIN
int byteGPS = -1;                 // Current read byte
char line[300] = "";              // Buffer
char commandGPR[7] = "$GPRMC";    // String related to messages

int counter=0;
int correctness=0;
int lineCounter=0;
int index[13];

void setup() {

  pinMode(rxPin, INPUT);
  Serial.begin(4800);

  // Clear buffer
  for (int i=0;i<300;i++){       
    line[i]=' ';
  }   
}


void loop() {

  byteGPS = Serial.read();         // Read a byte from the serial port

  // Test if the port is empty
  if (byteGPS == -1) {           
    delay(100); 
  }

  else {  // if it isn't empty

    line[lineCounter] = byteGPS;   // put data read in the buffer
    lineCounter++;

    Serial.print(byteGPS);   // print data read to the serial monitor

    // Test if the transmission is finished
    // if it is finished, we begin to parse !
    if (byteGPS==13){                    

      counter=0;
      correctness=0;

      // Test if the received command starts by $GPR
      // If it does, increase correctness counter
      for (int i=1;i<7;i++){
        if (line[i]==commandGPR[i-1]){
          correctness++;
        }
      }


      if(correctness==6){
        // We are sure command is okay here.

        // 
        for (int i=0;i<300;i++){

          // store position of "," separators
          if (line[i]==','){    
            index[counter]=i;
            counter++;
          }

          // store position of "*" separator meaning the last byte
          if (line[i]=='*'){    // ... and the "*"
            index[12]=i;
            counter++;
          }
        }

        // Write data to serial monitor on the computer
        Serial.println("");
        Serial.println("");
        Serial.println("---------------");
        for (int i=0;i<12;i++){
          switch(i){
          case 0 :
            Serial.print("Time in UTC (HhMmSs): ");
            break;
          case 1 :
            Serial.print("Status (A=OK,V=KO): ");
            break;
          case 2 :
            Serial.print("Latitude: ");
            break;
          case 3 :
            Serial.print("Direction (N/S): ");
            break;
          case 4 :
            Serial.print("Longitude: ");
            break;
          case 5 :
            Serial.print("Direction (E/W): ");
            break;
          case 6 :
            Serial.print("Velocity in knots: ");
            break;
          case 7 :
            Serial.print("Heading in degrees: ");
            break;
          case 8 :
            Serial.print("Date UTC (DdMmAa): ");
            break;
          case 9 :
            Serial.print("Magnetic degrees: ");
            break;
          case 10 :
            Serial.print("(E/W): ");
            break;
          case 11 :
            Serial.print("Mode: ");
            break;
          case 12 :
            Serial.print("Checksum: ");
            break;
          }
          for (int j=index[i];j<(index[i+1]-1);j++){
            Serial.print(line[j+1]); 
          }
          Serial.println("");
        }
        Serial.println("---------------");
      }

      // Reset the buffer
      lineCounter=0;                    
      for (int i=0;i<300;i++){
        line[i]=' ';             
      }                 
    }
  }
}
