/*
  processingOneSwitchDisplay is a very cheap display for visualizing
  Arduino's switch activities.
  
  Written by Julien Bayle, this example code is under Creative Commons CC-BY-SA
 
 This code is related to the book "C programming for Arduino" written by Julien Bayle
 and published by Packt Publishing.
 
 http://cprogrammingforarduino.com
 
 */

import processing.serial.*;

Serial theSerialPort;                 // create the serial port object
int[] serialBytesArray = new int[2];  // array storing current message
int switchID;                         // index of the switch
int switchState;                      // current switch state
int bytesCount = 0;                   // current number of bytes relative to messages
boolean init = false;                 // init state
int fillColor = 40;                   // defining the initial fill color

void setup(){
  
  // define some canvas and drawing parameters
  size(500,500);
  background(70);
  noStroke();
  
  // printing the list of all serial devices (debug purpose)
  println(Serial.list());
  
  // On osx, the Arduino port is the first into the list
  String thePortName = Serial.list()[0];
  
  // Instantate the Serial Communication
  theSerialPort = new Serial(this, thePortName, 9600);
}

void draw(){
  
  // set the fill color
  fill(fillColor);
  
  // draw a circle in the middle of the screen
  ellipse(width/2, height/2, 230, 230);
}


void serialEvent(Serial myPort) {
  
  // read a byte from the serial port
  int inByte = myPort.read();
  
  if (init == false) {         // if this is the first hello
    if (inByte == 'Z') {       // if the byte read is Z
      myPort.clear();          // clear the serial port buffer
      init = true;             // store the fact we had the first hello
      myPort.write('Z');       // tell the Arduino to send more !
    } 
  } 
  else {                       // if there already was the first hello
  
    // Add the latest byte from the serial port to array
    serialBytesArray[bytesCount] = inByte;
    bytesCount++;

    // if the messages is 2 bytes length
    if (bytesCount > 1 ) {
      switchID = serialBytesArray[0];      // store the ID of the concerned switch  (future implementation)
      switchState = serialBytesArray[1];   // store the state of the concerned switch
 
      // print the values (for debugging purposes):
      println(switchID + "\t" + switchState);

      // alter the fill color according to the message received from Arduino
      if (switchState == 0) fillColor = 40;
      else fillColor = 255;
      
      
      // Send a capital Z to request new sensor readings
      myPort.write('Z');
      
      // Reset bytesCount:
      bytesCount = 0;
    }
  }
}
